from concurrent.futures import ThreadPoolExecutor, ProcessPoolExecutor
from more_executors._wrap import CanCustomizeBind


class CustomizableThreadPoolExecutor(CanCustomizeBind, ThreadPoolExecutor):
    pass


class CustomizableProcessPoolExecutor(CanCustomizeBind, ProcessPoolExecutor):
    pass



from ._apply import f_apply
from ._bool import f_or, f_and
from ._base import f_return, f_return_error, f_return_cancelled
from ._zip import f_zip
from ._map import f_map, f_flat_map
from ._sequence import f_traverse, f_sequence
from ._nocancel import f_nocancel
from ._timeout import f_timeout

__all__ = ['f_apply', 'f_or', 'f_and',
           'f_return', 'f_return_error', 'f_return_cancelled',
           'f_zip', 'f_map', 'f_flat_map',
           'f_traverse', 'f_sequence', 'f_nocancel', 'f_timeout']
